# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'ArchiveRuleFilter',
]

@pulumi.output_type
class ArchiveRuleFilter(dict):
    def __init__(__self__, *,
                 criteria: str,
                 contains: Optional[Sequence[str]] = None,
                 eqs: Optional[Sequence[str]] = None,
                 exists: Optional[str] = None,
                 neqs: Optional[Sequence[str]] = None):
        """
        :param str criteria: Filter criteria.
        :param Sequence[str] contains: Contains comparator.
        :param Sequence[str] eqs: Equals comparator.
        :param str exists: Boolean comparator.
        :param Sequence[str] neqs: Not Equals comparator.
        """
        pulumi.set(__self__, "criteria", criteria)
        if contains is not None:
            pulumi.set(__self__, "contains", contains)
        if eqs is not None:
            pulumi.set(__self__, "eqs", eqs)
        if exists is not None:
            pulumi.set(__self__, "exists", exists)
        if neqs is not None:
            pulumi.set(__self__, "neqs", neqs)

    @property
    @pulumi.getter
    def criteria(self) -> str:
        """
        Filter criteria.
        """
        return pulumi.get(self, "criteria")

    @property
    @pulumi.getter
    def contains(self) -> Optional[Sequence[str]]:
        """
        Contains comparator.
        """
        return pulumi.get(self, "contains")

    @property
    @pulumi.getter
    def eqs(self) -> Optional[Sequence[str]]:
        """
        Equals comparator.
        """
        return pulumi.get(self, "eqs")

    @property
    @pulumi.getter
    def exists(self) -> Optional[str]:
        """
        Boolean comparator.
        """
        return pulumi.get(self, "exists")

    @property
    @pulumi.getter
    def neqs(self) -> Optional[Sequence[str]]:
        """
        Not Equals comparator.
        """
        return pulumi.get(self, "neqs")


