# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
from .. import _utilities

__all__ = [
    'OrganizationConfigurationAutoEnable',
]

@pulumi.output_type
class OrganizationConfigurationAutoEnable(dict):
    @staticmethod
    def __key_warning(key: str):
        suggest = None
        if key == "lambda":
            suggest = "lambda_"

        if suggest:
            pulumi.log.warn(f"Key '{key}' not found in OrganizationConfigurationAutoEnable. Access the value via the '{suggest}' property getter instead.")

    def __getitem__(self, key: str) -> Any:
        OrganizationConfigurationAutoEnable.__key_warning(key)
        return super().__getitem__(key)

    def get(self, key: str, default = None) -> Any:
        OrganizationConfigurationAutoEnable.__key_warning(key)
        return super().get(key, default)

    def __init__(__self__, *,
                 ec2: bool,
                 ecr: bool,
                 lambda_: Optional[bool] = None):
        """
        :param bool ec2: Whether Amazon EC2 scans are automatically enabled for new members of your Amazon Inspector organization.
        :param bool ecr: Whether Amazon ECR scans are automatically enabled for new members of your Amazon Inspector organization.
        :param bool lambda_: Whether Lambda Function scans are automatically enabled for new members of your Amazon Inspector organization.
        """
        pulumi.set(__self__, "ec2", ec2)
        pulumi.set(__self__, "ecr", ecr)
        if lambda_ is not None:
            pulumi.set(__self__, "lambda_", lambda_)

    @property
    @pulumi.getter
    def ec2(self) -> bool:
        """
        Whether Amazon EC2 scans are automatically enabled for new members of your Amazon Inspector organization.
        """
        return pulumi.get(self, "ec2")

    @property
    @pulumi.getter
    def ecr(self) -> bool:
        """
        Whether Amazon ECR scans are automatically enabled for new members of your Amazon Inspector organization.
        """
        return pulumi.get(self, "ecr")

    @property
    @pulumi.getter(name="lambda")
    def lambda_(self) -> Optional[bool]:
        """
        Whether Lambda Function scans are automatically enabled for new members of your Amazon Inspector organization.
        """
        return pulumi.get(self, "lambda_")


